@@ -1,6 +1,6 @@
 /* test_libFLAC - Unit tester for libFLAC
  * Copyright (C) 2002-2009  Josh Coalson
- * Copyright (C) 2011-2013  Xiph.Org Foundation
+ * Copyright (C) 2011-2014  Xiph.Org Foundation
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@
  * These are not tests, just utility functions used by the metadata tests
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
@@ -487,14 +487,14 @@ void mutils__init_metadata_blocks(
 	application1->is_last = false;
 	application1->type = FLAC__METADATA_TYPE_APPLICATION;
 	application1->length = 8;
-	memcpy(application1->data.application.id, "\xfe\xdc\xba\x98", 4);
+	memcpy(application1->data.application.id, "This", 4);
 	application1->data.application.data = malloc_or_die_(4);
 	memcpy(application1->data.application.data, "\xf0\xe1\xd2\xc3", 4);
 
 	application2->is_last = false;
 	application2->type = FLAC__METADATA_TYPE_APPLICATION;
 	application2->length = 4;
-	memcpy(application2->data.application.id, "\x76\x54\x32\x10", 4);
+	memcpy(application2->data.application.id, "Here", 4);
 	application2->data.application.data = 0;
 
 	{
